==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/fragments-widgets/components/TabItem.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/fragments-widgets/components/TabItem", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/icon', '@frontend-taglib-clay$clayui/popover', 'frontend-js-react-web$classnames', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../app/config/constants/layoutDataItemTypes', '../../../app/selectors/selectSegmentsExperienceId', '../../../app/store/index', '../../../app/thunks/addFragment', '../../../app/thunks/addItem', '../../../app/thunks/addWidget', '../../../app/utils/dragAndDrop/useDragAndDrop'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = TabItem;

    var _button = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button"));

    var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

    var _popover = _interopRequireDefault(require("@frontend-taglib-clay$clayui/popover"));

    var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _layoutDataItemTypes = require("../../../app/config/constants/layoutDataItemTypes");

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../app/selectors/selectSegmentsExperienceId"));

    var _index = require("../../../app/store/index");

    var _addFragment = _interopRequireDefault(require("../../../app/thunks/addFragment"));

    var _addItem = _interopRequireDefault(require("../../../app/thunks/addItem"));

    var _addWidget = _interopRequireDefault(require("../../../app/thunks/addWidget"));

    var _useDragAndDrop = require("../../../app/utils/dragAndDrop/useDragAndDrop");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    function TabItem(_ref) {
      var item = _ref.item;
      var dispatch = (0, _index.useDispatch)();
      var segmentsExperienceId = (0, _index.useSelector)(_selectSegmentsExperienceId["default"]);

      var _useState = (0, _react.useState)(false),
          _useState2 = _slicedToArray(_useState, 2),
          showPreview = _useState2[0],
          setShowPreview = _useState2[1];

      var _useDragSymbol = (0, _useDragAndDrop.useDragSymbol)({
        icon: item.icon,
        label: item.label,
        type: item.type
      }, function (parentId, position) {
        var thunk;

        if (item.type === _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.fragment) {
          if (item.data.portletId) {
            thunk = _addWidget["default"];
          } else {
            thunk = _addFragment["default"];
          }
        } else {
          thunk = _addItem["default"];
        }

        dispatch(thunk(_objectSpread({}, item.data, {
          parentItemId: parentId,
          position: position,
          store: {
            segmentsExperienceId: segmentsExperienceId
          }
        })));
      }),
          sourceRef = _useDragSymbol.sourceRef;

      return _react["default"].createElement("li", {
        className: (0, _classnames["default"])('page-editor__fragments-widgets__tab-item', {
          disabled: item.disabled
        }),
        ref: item.disabled ? null : sourceRef
      }, _react["default"].createElement("div", {
        className: "page-editor__fragments-widgets__tab-item-body"
      }, _react["default"].createElement(_icon["default"], {
        className: "mr-3",
        symbol: item.icon
      }), _react["default"].createElement("div", {
        className: "text-truncate title"
      }, item.label)), item.preview && _react["default"].createElement("div", {
        className: "page-editor__fragments-widgets__tab-item-preview"
      }, _react["default"].createElement(_button["default"], {
        className: "btn-monospaced preview-icon",
        displayType: "unstyled",
        onBlur: function onBlur() {
          return setShowPreview(false);
        },
        onFocus: function onFocus() {
          return setShowPreview(true);
        },
        onMouseLeave: function onMouseLeave() {
          return setShowPreview(false);
        },
        onMouseOver: function onMouseOver() {
          return setShowPreview(true);
        },
        small: true
      }, _react["default"].createElement(_icon["default"], {
        symbol: "info-circle-open"
      }), _react["default"].createElement("span", {
        className: "sr-only"
      }, name)), showPreview && _react["default"].createElement(_popover["default"], {
        disableScroll: true
      }, _react["default"].createElement("img", {
        alt: "thumbnail",
        src: item.preview
      }))));
    }
    //# sourceMappingURL=TabItem.js.map
  }
});
//# sourceMappingURL=TabItem.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/fragments-widgets/components/TabItem.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/fragments-widgets/components/TabItem", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/icon', '@frontend-taglib-clay$clayui/popover', 'frontend-js-react-web$classnames', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../app/config/constants/layoutDataItemTypes', '../../../app/selectors/selectSegmentsExperienceId', '../../../app/store/index', '../../../app/thunks/addFragment', '../../../app/thunks/addItem', '../../../app/thunks/addWidget', '../../../app/utils/dragAndDrop/useDragAndDrop'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = TabItem;

    var _button = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button"));

    var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

    var _popover = _interopRequireDefault(require("@frontend-taglib-clay$clayui/popover"));

    var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _layoutDataItemTypes = require("../../../app/config/constants/layoutDataItemTypes");

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../app/selectors/selectSegmentsExperienceId"));

    var _index = require("../../../app/store/index");

    var _addFragment = _interopRequireDefault(require("../../../app/thunks/addFragment"));

    var _addItem = _interopRequireDefault(require("../../../app/thunks/addItem"));

    var _addWidget = _interopRequireDefault(require("../../../app/thunks/addWidget"));

    var _useDragAndDrop = require("../../../app/utils/dragAndDrop/useDragAndDrop");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    function TabItem(_ref) {
      var item = _ref.item;
      var dispatch = (0, _index.useDispatch)();
      var segmentsExperienceId = (0, _index.useSelector)(_selectSegmentsExperienceId.default);

      var _useState = (0, _react.useState)(false),
          _useState2 = _slicedToArray(_useState, 2),
          showPreview = _useState2[0],
          setShowPreview = _useState2[1];

      var _useDragSymbol = (0, _useDragAndDrop.useDragSymbol)({
        icon: item.icon,
        label: item.label,
        type: item.type
      }, function (parentId, position) {
        var thunk;

        if (item.type === _layoutDataItemTypes.LAYOUT_DATA_ITEM_TYPES.fragment) {
          if (item.data.portletId) {
            thunk = _addWidget.default;
          } else {
            thunk = _addFragment.default;
          }
        } else {
          thunk = _addItem.default;
        }

        dispatch(thunk(_objectSpread(_objectSpread({}, item.data), {}, {
          parentItemId: parentId,
          position: position,
          store: {
            segmentsExperienceId: segmentsExperienceId
          }
        })));
      }),
          sourceRef = _useDragSymbol.sourceRef;

      return (/*#__PURE__*/_react.default.createElement("li", {
          className: (0, _classnames.default)('page-editor__fragments-widgets__tab-item', {
            disabled: item.disabled,
            'page-editor__fragments-widgets__tab-portlet-item': item.data.portletItemId
          }),
          ref: item.disabled ? null : sourceRef
        }, /*#__PURE__*/_react.default.createElement("div", {
          className: "page-editor__fragments-widgets__tab-item-body"
        }, /*#__PURE__*/_react.default.createElement(_icon.default, {
          className: "mr-3",
          symbol: item.icon
        }), /*#__PURE__*/_react.default.createElement("div", {
          className: "text-truncate title"
        }, item.label)), item.preview && /*#__PURE__*/_react.default.createElement("div", {
          className: "page-editor__fragments-widgets__tab-item-preview"
        }, /*#__PURE__*/_react.default.createElement(_button.default, {
          className: "btn-monospaced preview-icon",
          displayType: "unstyled",
          onBlur: function onBlur() {
            return setShowPreview(false);
          },
          onFocus: function onFocus() {
            return setShowPreview(true);
          },
          onMouseLeave: function onMouseLeave() {
            return setShowPreview(false);
          },
          onMouseOver: function onMouseOver() {
            return setShowPreview(true);
          },
          small: true
        }, /*#__PURE__*/_react.default.createElement(_icon.default, {
          symbol: "info-circle-open"
        }), /*#__PURE__*/_react.default.createElement("span", {
          className: "sr-only"
        }, name)), showPreview && /*#__PURE__*/_react.default.createElement(_popover.default, {
          disableScroll: true
        }, /*#__PURE__*/_react.default.createElement("img", {
          alt: "thumbnail",
          src: item.preview
        }))))
      );
    }
    //# sourceMappingURL=TabItem.js.map
  }
});
//# sourceMappingURL=TabItem.js.map
